==> twitter_api_block-8.x-2.0.tar.gz: twitter_api_block/src/Plugin/Block/TwitterHashtagBlock.php <==
<?php

namespace Drupal\twitter_api_block\Plugin\Block;

use Drupal\Component\Serialization\Json;
use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Cache\UncacheableDependencyTrait;
use Drupal\Core\Form\FormStateInterface;
use TwitterAPIExchange;

/**
 * Provides a 'TwitterHashtagBlock' block.
 *
 * @Block(
 *   id = "twitter_hashtag_block",
 *   admin_label = @Translation("Twitter - Hashtag block"),
 *   category = @Translation("Content")
 * )
 */
class TwitterHashtagBlock extends TwitterBlockBase {

  use UncacheableDependencyTrait;

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $config = $this->getConfiguration();

    // Block options.
    $form['options']['hashtag'] = [
      '#type' => 'textfield',
      '#title' => $this->t("Hashtag"),
      '#description' => $this->t("without the # sign."),
      '#default_value' => isset($config['options']['hashtag']) ? $config['options']['hashtag'] : NULL,
      '#required' => TRUE,
    ];
    $form['options']['result_type'] = [
      '#type' => 'select',
      '#options' => [
        'mixed' => $this->t('mixed'),
        'recent' => $this->t('Recent'),
        'popular' => $this->t('Popular'),
      ],
      '#title' => $this->t("Result type"),
      '#default_value' => isset($config['options']['result_type']) ? $config['options']['result_type'] : 'popular',
      '#required' => TRUE,
    ];
    $form['options']['lang'] = [
      '#type' => 'select',
      '#options' => [
        'en' => $this->t('EN'),
        'fr' => $this->t('FR'),
        'es' => $this->t('ES'),
      ],
      '#title' => $this->t("Language"),
      '#default_value' => isset($config['options']['lang']) ? $config['options']['lang'] : 3,
    ];
    $form['options']['geocode'] = [
      '#type' => 'textfield',
      '#title' => $this->t("Geocode"),
      '#default_value' => isset($config['options']['geocode']) ? $config['options']['geocode'] : NULL,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = parent::build();
    $config = $this->getConfiguration();
    $settings = $this->settings;

    // Get latest tweets.
    $tweets = [];
    try {
      $url = 'https://api.twitter.com/1.1/search/tweets.json';
      $twitter = new TwitterAPIExchange($settings);
      $params = static::getParameters($config);
      $result = $twitter->setGetfield($params)->buildOauth($url, 'GET')->performRequest();
      $latest = Json::decode($result);

      $i = 0;
      foreach ($latest['statuses'] as $tweet) {
        $username = $tweet['user']['screen_name'];

        if (isset($tweet['id']) && $i < $config['options']['count']) {
          $url = 'https://publish.twitter.com/oembed?url=https%3A%2F%2Ftwitter.com%2F' . $username . '%2Fstatus%2F' . $tweet['id'];
          $data = $twitter->buildOauth($url, 'GET')->performRequest();
          $tweets[] = Json::decode($data);
        }
        $i++;
      }
    } catch (\Exception $e) {
      \Drupal::logger('twitter')->error($e->getMessage());
    }

    // Build renderable array of oembed tweets.
    if (count($tweets)) {
      $build['tweets'] = [];
      foreach ($tweets as $tweet) {
        $build['tweets'][] = ['#markup' => $tweet['html']];
      }
    }

    // Pass account name to Twig.
    $build['username'] = [
      '#type' => 'item',
      '#markup' => $config['options']['username'],
    ];

    return $build;
  }

  /**
   * {@inheritDoc}
   */
  private static function getParameters($config) {
    return UrlHelper::buildQuery([
      'q' => '#' . $config['options']['hashtag'],
      'count' => $config['options']['count'],
      'result_type' => $config['options']['lang'],
      'lang' => $config['options']['lang'],
      'geocode' => $config['options']['geocode'],
    ]);
  }
}

==> twitter_api_block-8.x-2.1.tar.gz: twitter_api_block/src/Plugin/Block/TwitterHashtagBlock.php <==
<?php

namespace Drupal\twitter_api_block\Plugin\Block;

use Drupal\Component\Serialization\Json;
use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Cache\UncacheableDependencyTrait;
use Drupal\Core\Form\FormStateInterface;
use TwitterAPIExchange;

/**
 * Provides a 'TwitterHashtagBlock' block.
 *
 * @Block(
 *   id = "twitter_hashtag_block",
 *   admin_label = @Translation("Twitter - Hashtag block"),
 *   category = @Translation("Content")
 * )
 */
class TwitterHashtagBlock extends TwitterBlockBase {

  use UncacheableDependencyTrait;

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $config = $this->getConfiguration();

    // Block options.
    $form['options']['hashtag'] = [
      '#type' => 'textfield',
      '#title' => $this->t("Hashtag"),
      '#description' => $this->t("without the # sign."),
      '#default_value' => isset($config['options']['hashtag']) ? $config['options']['hashtag'] : NULL,
      '#required' => TRUE,
    ];
    $form['options']['result_type'] = [
      '#type' => 'select',
      '#options' => [
        'mixed' => $this->t('mixed'),
        'recent' => $this->t('Recent'),
        'popular' => $this->t('Popular'),
      ],
      '#title' => $this->t("Result type"),
      '#default_value' => isset($config['options']['result_type']) ? $config['options']['result_type'] : 'popular',
      '#required' => TRUE,
    ];
    $form['options']['lang'] = [
      '#type' => 'select',
      '#options' => [
        'en' => $this->t('EN'),
        'fr' => $this->t('FR'),
        'es' => $this->t('ES'),
      ],
      '#title' => $this->t("Language"),
      '#default_value' => isset($config['options']['lang']) ? $config['options']['lang'] : 3,
    ];
    $form['options']['geocode'] = [
      '#type' => 'textfield',
      '#title' => $this->t("Geocode"),
      '#default_value' => isset($config['options']['geocode']) ? $config['options']['geocode'] : NULL,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = parent::build();
    $config = $this->getConfiguration();
    $settings = $this->settings;

    // Get latest tweets.
    $tweets = [];
    try {
      $url = 'https://api.twitter.com/1.1/search/tweets.json';
      $twitter = new TwitterAPIExchange($settings);
      $params = static::getParameters($config);
      $result = $twitter->setGetfield($params)->buildOauth($url, 'GET')->performRequest();
      $latest = Json::decode($result);

      $i = 0;
      foreach ($latest['statuses'] as $tweet) {
        $username = $tweet['user']['screen_name'];

        if (isset($tweet['id']) && $i < $config['options']['count']) {
          $url = 'https://publish.twitter.com/oembed?url=https%3A%2F%2Ftwitter.com%2F' . $username . '%2Fstatus%2F' . $tweet['id'];
          $data = $twitter->buildOauth($url, 'GET')->performRequest();
          $tweets[] = Json::decode($data);
        }
        $i++;
      }
    } catch (\Exception $e) {
      \Drupal::logger('twitter')->error($e->getMessage());
    }

    // Build renderable array of oembed tweets.
    if (count($tweets)) {
      $build['tweets'] = [];
      foreach ($tweets as $tweet) {
        $build['tweets'][] = ['#markup' => $tweet['html']];
      }
    }

    // Pass hashtag to Twig.
    $build['hashtag'] = [
      '#type' => 'item',
      '#markup' => $config['options']['hashtag'],
    ];

    return $build;
  }

  /**
   * {@inheritDoc}
   */
  private static function getParameters($config) {
    return UrlHelper::buildQuery([
      'q' => '#' . $config['options']['hashtag'],
      'count' => $config['options']['count'],
      'result_type' => $config['options']['lang'],
      'lang' => $config['options']['lang'],
      'geocode' => $config['options']['geocode'],
    ]);
  }
}
